@@ -58,7 +58,8 @@ class Serialization(WikiSerialization):
         if not wiki:
             wiki = WikiSerialization._get_wiki(self)
         tag = "<!--POST-SCRIPT-START-->"
-        wiki = wiki.replace(tag, '''\
-<script type="text/javascript" src="/bags/common/tiddlers/backstage.js"></script>
+        if not download:
+            wiki = wiki.replace(tag,
+'''<script type="text/javascript" src="/bags/common/tiddlers/backstage.js"></script>
 %s''' % tag)
         return wiki
