@@ -9,7 +9,7 @@ https://raw.github.com/bengillies/chrjs.store/master/dist/chrjs-store-latest.js
  *
  * Dependencies: chrjs library, jQuery, TiddlySpace
  *
- * Version: 0.6.1
+ * Version: 0.6.3
  *
  * created by Ben Gillies
  * Chrjs-Store is distributed under a BSD License
@@ -333,8 +333,8 @@ var states = {
 		},
 		tiddlerTest: function(value) {
 			return function(tiddler) {
-				var matches = (tiddler[value.field] || (tiddler.fields &&
-					tiddler.fields[value.field]) === value.value) ?
+				var matches = ((tiddler[value.field] || (tiddler.fields &&
+					tiddler.fields[value.field])) === value.value) ?
 						true : false;
 				return (value.not) ? !matches : matches;
 			};
@@ -1546,7 +1546,7 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 		} else if (callback && args.title) {
 			self.getDefaults(function(container) {
 				var tid = new tiddlyweb.Tiddler(args.title, container.pullFrom);
-				tid.get(success, error);
+				tid.get(success, error, (render) ? 'render=1' : '');
 			});
 		}
 
